@@ -64,10 +64,10 @@ class ParseMCNPCell:
                                           'are not supported yet')
 
     def parse_importance_cards(self):
-        '''Parse any importance cards and return the minimum importance value
+        '''Parse any importance cards and return the maximum importance value
         for each cell.
 
-        :returns: the minimum importances.
+        :returns: the maximum importances.
         :rtype: list(float)
         '''
         importance_cards = get_cell_importances(self.mcnp_parser)
@@ -85,8 +85,8 @@ class ParseMCNPCell:
             raise ParseMCNPCellError(msg)
         if len(lens) == 1:
             return importances[0]
-        min_importances = [min(*values) for values in zip(*importances)]
-        return min_importances
+        max_importances = [max(*values) for values in zip(*importances)]
+        return max_importances
 
     def parse(self):
         '''
@@ -160,8 +160,10 @@ class ParseMCNPCell:
 
         ast_mcnp = get_ast(geometry)
 
-        kw_list = list(reversed(option.lower().replace('(', ' ')
-                                .replace(')', ' ').replace('=', ' ').split()))
+        option = re.sub(' *: *', ':', option)
+        option = (option.lower().replace('(', ' ').replace(')', ' ')
+                  .replace('=', ' '))
+        kw_list = list(reversed(option.split()))
         kws = self.parse_keywords(kw_list)
 
         # replace some missing values with the defaults
@@ -230,7 +232,7 @@ class ParseMCNPCell:
             if elt.startswith('imp'):
                 importance = float(kw_list.pop())
                 if 'importance' in keywords:
-                    keywords['importance'] = min(importance,
+                    keywords['importance'] = max(importance,
                                                  keywords['importance'])
                 else:
                     keywords['importance'] = importance
@@ -291,6 +293,7 @@ class ParseMCNPCell:
                             0., 1., 0.,
                             0., 0., 1.]
         elif '*' in elt:
+            fill_params = [float(x) for x in fill_params]
             fill_params[3:] = list(map(to_cos, fill_params[3:12]))
             fill_params = normalize_transform(fill_params)
         elif fill_params:
@@ -333,5 +336,6 @@ class ParseMCNPCell:
                             0., 1., 0.,
                             0., 0., 1.]
         elif '*' in elt:
+            trcl_params = [float(x) for x in trcl_params]
             trcl_params[3:] = list(map(to_cos, trcl_params[3:12]))
         return tuple(trcl_params)
