@@ -1,21 +1,30 @@
-# -*- coding: utf-8 -*-
-'''
-Created on 6 févr. 2019
-
-:author: Sogeti
-:data : 06 february 2019
-:file : CIntermediateGeomCompT4.py
-'''
+# Copyright 2019-2021 Davide Mancusi, Martin Maurey, Jonathan Faustin
+#
+# This file is part of t4_geom_convert.
+#
+# t4_geom_convert is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# t4_geom_convert is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# t4_geom_convert.  If not, see <https://www.gnu.org/licenses/>.
+#
+# vim: set fileencoding=utf-8 :
 
 from .CDictGeomCompT4 import CDictGeomCompT4
 from .CGeomCompT4 import CGeomCompT4
 from collections import defaultdict, OrderedDict
 
+
 def constructGeomCompT4(dicVol, dic_cellMCNP):
-    '''
-    :brief: method constructing a dictionary with the id of the
-    material as a key and the instance of CGeomCompT4 as a value
-    '''
+    '''Method constructing a dictionary with the id of the material as a key
+    and the instance of CGeomCompT4 as a value.'''
     dic_geomCompT4 = OrderedDict()
     dic_partialGeomComp = OrderedDict()
     obj_T4 = CDictGeomCompT4(dic_geomCompT4)
@@ -37,5 +46,6 @@ def constructGeomCompT4(dicVol, dic_cellMCNP):
     for key in dic_partialGeomComp.keys():
         numberOfCell = len(dic_partialGeomComp[key])
         listCell = dic_partialGeomComp[key]
-        obj_T4[key] = CGeomCompT4(numberOfCell, " ".join(str(x) for x in listCell))
+        obj_T4[key] = CGeomCompT4(
+            numberOfCell, " ".join(str(x) for x in listCell))
     return obj_T4.geomCompT4
