@@ -17,6 +17,7 @@
 #
 # vim: set fileencoding=utf-8 :
 
+from warnings import warn
 from math import sqrt
 from collections import OrderedDict
 import numpy as np
@@ -29,7 +30,8 @@ from .TransformationQuad import transformation_quad
 from .TransformationError import TransformationError
 
 from ..Surface.ESurfaceTypeMCNP import ESurfaceTypeMCNP as MS
-from ..VectUtils import transpose, matrix_rows, scal, renorm, vdiff, vect
+from ..VectUtils import (transpose, matrix_rows, scal, renorm, vdiff, vect,
+                         mag2, mag, rescale)
 
 
 def get_mcnp_transforms(parser):
@@ -46,9 +48,9 @@ def get_mcnp_transforms(parser):
         try:
             transf = normalize_transform(transf)
         except TransformationError as err:
-            raise TransformationError('{}\nThe problematic transformation '
-                                      'was TR{}={}'
-                                      .format(err, transf_id, transf))
+            msg = (f'{err}\nThe problematic transformation was '
+                   f'TR{transf_id}={transf}')
+            raise TransformationError(msg) from None
         transforms[transf_id] = transf
     return transforms
 
@@ -59,7 +61,26 @@ def normalize_transform(transf):
     if len(transf) == 13 and transf[-1] != 1:
         raise TransformationError('Transformations with m=-1 are not supported'
                                   ' yet.')
-    return transf[:3] + normalize_matrix(transf[3:12])
+    if not transf:
+        return [0.0, 0.0, 0.0,
+                1.0, 0.0, 0.0,
+                0.0, 1.0, 0.0,
+                0.0, 0.0, 1.0]
+
+    if len(transf) == 3:
+        return list(transf) + [1.0, 0.0, 0.0,
+                               0.0, 1.0, 0.0,
+                               0.0, 0.0, 1.0]
+
+    matrix = normalize_matrix(transf[3:12])
+    npmat = np.array(matrix).reshape(3,3)
+    adjusted_matrix = adjust_matrix(matrix)
+    adjusted_npmat = np.array(adjusted_matrix).reshape(3,3)
+    adjusted_tr = np.array(transf[:3])
+    # adjusted_tr = adjusted_npmat.T.dot(npmat.dot(transf[:3]))
+    # diff = adjusted_tr - np.array(transf[:3])
+    # dist = mag(diff)
+    return list(adjusted_tr.flat) + adjusted_matrix
 
 
 def normalize_matrix(matrix):  # pylint: disable=too-many-return-statements
@@ -96,9 +117,102 @@ def normalize_matrix(matrix):  # pylint: disable=too-many-return-statements
             return normalize_matrix6(matrix9)
         # two columns were defined; transpose, normalize and transpose back
         return transpose(normalize_matrix6(transpose(matrix9)))
-    raise TransformationError('Malformed matrix {} has {} non-None elements; '
-                              '0, 3, 5, 6 or 9 elements are expected'
-                              .format(matrix, n_values))
+    raise TransformationError(f'Malformed matrix {matrix} has {n_values} '
+                              'non-None elements; 0, 3, 5, 6 or 9 elements '
+                              'are expected')
+
+
+def adjust_matrix(matrix):
+    '''Perform a certain number of magical tweaks to the matrix that make sure
+    that it is orthogonal.
+
+    MCNP tolerates some skewness but internally adjusts the matrix. We need to
+    do the same thing, or we will not generate the same geometry.
+
+    >>> adjust_matrix([1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0])
+    [1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0]
+
+    >>> from math import cos, sin, isclose
+    >>> cos_a, sin_a = cos(1.23), sin(1.23)
+    >>> rot = [1.0, 0.0, 0.0, 0.0, cos_a, sin_a, 0.0, -sin_a, cos_a]
+    >>> rot2 = adjust_matrix(rot)
+    >>> all(isclose(x, y) for x, y in zip(rot, rot2))
+    True
+
+    The following matrix has too few significant digits, so
+    :func:`adjust_matrix` raises a warning:
+
+    >>> import pytest
+    >>> mat = [ 0.8021,  0.1056, -0.5878,
+    ...        -0.1305,  0.9914,  0.0000,
+    ...         0.5828,  0.0767,  0.8090]
+    >>> with pytest.warns(UserWarning, match='is not orthogonal'):
+    ...     mat2 = adjust_matrix(mat)
+
+    The new matrix is close to the original one, with a tolerance of 1e-4:
+
+    >>> all(isclose(x, y, abs_tol=1e-4) for x, y in zip(mat, mat2))
+    True
+
+    Based on r̶a̶t̶i̶o̶n̶a̶l̶ ̶g̶e̶o̶m̶e̶t̶r̶i̶c̶a̶l̶ ̶c̶o̶n̶s̶i̶d̶e̶r̶a̶t̶i̶o̶n̶s̶
+    c̶a̶r̶e̶f̶u̶l̶ ̶r̶e̶a̶d̶i̶n̶g̶ ̶o̶f̶ ̶t̶h̶e̶ ̶M̶C̶N̶P̶ ̶s̶o̶u̶r̶c̶e̶ ̶c̶o̶d̶e̶ desperate debugging with ``gdb``,
+    the adjusted matrix generated by MCNP is:
+
+    >>> mat2_expected = [
+    ...     0.80207826071476684, 0.10559100917526101, -0.58781034566441959,
+    ...     -0.13050431946672519, 0.99144774047316964, 2.260914180407525e-05,
+    ...     0.58278562635784137, 0.07669365483530112, 0.80899876206252763
+    ...     ]
+
+    The matrix generated by :func:`adjust_mat` is close to the expected value:
+
+    >>> all(isclose(x, y) for x, y in zip(mat2_expected, mat2))
+    True
+
+    The entries are really close to the expected values!
+
+    >>> for x, y in zip(mat2_expected, mat2):
+    ...     ratio = (x-y)/x
+    ...     print(f'{x: 20.18e} {y: 20.18e} {ratio: 7.5e}')
+     8.020782607147668442e-01  8.020782607147668442e-01  0.00000e+00
+     1.055910091752610136e-01  1.055910091752610136e-01  0.00000e+00
+    -5.878103456644195868e-01 -5.878103456644196978e-01 -1.88874e-16
+    -1.305043194667251938e-01 -1.305043194667251938e-01 -0.00000e+00
+     9.914477404731696364e-01  9.914477404731696364e-01  0.00000e+00
+     2.260914180407525009e-05  2.260914180407525348e-05 -1.49857e-16
+     5.827856263578413687e-01  5.827856263578413687e-01  0.00000e+00
+     7.669365483530111993e-02  7.669365483530111993e-02  0.00000e+00
+     8.089987620625276321e-01  8.089987620625278542e-01 -2.74468e-16
+
+    :param matrix: a list of 9 floats, representing the entries of a rotation
+        matrix.
+    :type matrix: list(float)
+    '''
+    rows = [renorm(row) for row in matrix_rows(matrix)]
+    cols = matrix_rows(transpose([value for row in rows for value in row]))
+    should_be_zeros = [abs(mag2(r) - 1.0) for r in cols]
+    scal_prods = [abs(scal(cols[0], cols[1])),
+                  abs(scal(cols[1], cols[2])),
+                  abs(scal(cols[2], cols[0]))]
+    tolerance = max(*should_be_zeros, *scal_prods)
+    if tolerance > 2.e-6:
+        warn(f'transformation {matrix} is not orthogonal')
+    v0_mag2 = mag2(cols[0])
+    v1_mag2 = mag2(cols[1])
+    v0_v1 = scal(cols[0], cols[1])
+    # new_v1_mag = v1_mag2*v0_mag2**2 - v0_mag2*v0_v1**2
+    # cols[1] = rescale(1.0/new_v1_mag,
+    #                   vdiff(rescale(v0_mag2, cols[1]),
+    #                         rescale(v0_v1, cols[0])))
+    # cols[0] = rescale(1.0/np.sqrt(v0_mag2), cols[0])
+    cols[1] = renorm(vdiff(rescale(v0_mag2, cols[1]),
+                           rescale(v0_v1, cols[0])))
+    cols[0] = renorm(cols[0])
+    vprod = renorm(vect(cols[0], cols[1]))
+    cols[2] = vprod if scal(vprod, cols[2]) > 0.0 else rescale(-1.0, vprod)
+    new_matrix = [value if abs(value) >= 1e-10 else 0.0
+                  for col in cols for value in col]
+    return transpose(new_matrix)
 
 
 def is_matrix_rowwise(matrix):
@@ -307,7 +421,7 @@ def transform_vector(trans, vec):
 def compose_transform(trans1, trans2):
     '''Compose `trans1` and `trans2`.
 
-    Returns trans2 o trans1 (i.e. `trans1` is applied first).
+    Returns `trans2 o trans1` (i.e. `trans1` is applied first).
     '''
     mat1, vec1 = to_numpy(trans1)
     mat2, vec2 = to_numpy(trans2)
